/*
 * gui.h
 * 
 * Copyright (C) 2006-2007 Josef Kufner <jk@myserver.cz>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 */
#ifndef NETBOARD_GUI_H
#define NETBOARD_GUI_H

#include <gtk/gtk.h>

#include "options.h"
#include "message.h"

enum {
	GUI_PAGE_DESK,
	GUI_PAGE_CHAT,
	GUI_PAGE_GAMELOG,
	GUI_PAGE_NETLOG,
	GUI_PAGE_MAX
};

enum {
	GUI_ICON_NONE = 0,
	GUI_ICON_TIP,
	GUI_ICON_INFO,
	GUI_ICON_QUESTION,
	GUI_ICON_WARNING,
	GUI_ICON_ERROR,
	GUI_ICON_MAX
};

struct s_gui {
	int is_online;
	int is_game;
	int is_paused;
	int is_locked;
	int is_onturn;
	int can_start_game;
	int can_end_game;
	int can_select_game;
	int can_select_role;
	int semafor;
};

/* option dialog widget */
typedef enum {
	GUI_ODW_T_NONE, GUI_ODW_T_ENTRY, GUI_ODW_T_CHECKBOX, GUI_ODW_T_NUMBER, GUI_ODW_T_COMBO
} GUI_ODW_TYPE;
typedef struct {
	GUI_ODW_TYPE type;
	GtkWidget *widget;
	char opt[OPTION_MAX_OPT_LEN];
} GUI_ODW;
typedef struct {
	char cat[OPTION_MAX_CAT_LEN], mod[OPTION_MAX_MOD_LEN];
	GSList *list;
	GMemChunk *mem_chunk;
	int ok_clicked;
	char notify_target;
} GUI_ODW_LIST;

extern struct s_gui gui;

extern GtkWidget *main_window;
extern GtkWidget *dialog_connect;
extern GtkWidget *dialog_about;
extern GtkWidget *dialog_game_select;
extern GtkWidget *dialog_option_browser;
extern GtkWidget *dialog_network_profiles;

void update_main_window(void);
void set_semaphore(int x);
void after_create_main_window(void);
void enable_board(void);
void disable_board(void);
void show_alert_icon(int page);
void erase_logs (void);
void append_to_chat(char *fmt, ...);
void append_to_netlog(char *fmt, ...);
void append_to_gamelog(char *fmt, ...);
void set_statusbar_text(gchar *fmt,...);
void set_statusbar_clock(int is_visible, int set_icon, gchar *fmt,...);
void set_statusbar_progress(int visible, gdouble fraction, gchar *fmt,...);
void show_error_message(GtkWidget *parent, char *title, char *fmt, ...);
void show_dialog_game_select(void);
void show_dialog_connect(void);
void switch_main_page(int page);
void wait_for_callback(void);
void show_option_browser(void);
void update_option_browser(void);
void update_playerlist(void);
void store_options_with_info(void);
void gui_role_clear(void);
void gui_role_add(char *role);
int gui_exit_question(void);
int config_dialog_from_message(MESSAGE * msg, int notify_target);
int config_dialog_from_message_wp(MESSAGE * msg, int notify_target, GtkWidget *parent_window);
void show_network_profiles (void);
void update_network_profiles (void);
void show_network_profile_editor(char *id, GtkWidget *parent_window);
void show_network_backend_config(const char *id);

#endif
